@@ -25,11 +25,14 @@ def metrics(func, X, y, kind, formatstr="{:,.2f}"):
 
 def largest_errors(func, X, y, n=25):
     """Return observations with largest errors in predictions"""
-    cols = X.columns.to_list()
+    pred = func(X)
+    if isinstance(pred, pd.Series):
+        pred = pred.to_numpy()
+
     df = (
         X.copy()
         .assign(
-            y=y, pred=func(X).to_numpy()
+            y=y, pred=pred
         )  # to numpy is needed to help time inference
         .astype({"y": float, "pred": float})  # account for boolean output/predictions
         .assign(Delta=lambda x: np.abs(x["y"] - x["pred"]))
@@ -49,12 +52,15 @@ def largest_errors(func, X, y, n=25):
 
 def calibration(func, X, y, bins=10):
     """Plot calibration"""
-    pred = func(X)
-    pred_grp = pd.qcut(pred, q=bins, duplicates="drop")
+    preds = func(X)
+    if isinstance(preds, pd.Series):
+        preds = preds.to_numpy()
+
+    pred_grp = pd.qcut(preds, q=bins, duplicates="drop")
 
     df = pd.DataFrame(
         # conversion to numpy is required so booleans are handled correctly
-        {"Actual Value": y.to_numpy(), "Predicted Value": pred, "Group": pred_grp}
+        {"Actual Value": y.to_numpy(), "Predicted Value": preds, "Group": pred_grp}
     )
     df = df.groupby("Group").agg("mean").reset_index().drop(columns=["Group"])
 
