@@ -2,7 +2,6 @@ import json
 import logging
 import os
 
-import pandas
 from fastapi.encoders import jsonable_encoder
 
 from .accuracy import calibration, largest_errors, metrics
@@ -13,15 +12,22 @@ from .shap import ShapExplainer
 from .utils import create_description, df_to_dict
 
 
-def create_shapley_schema(endpoint, basepath="results"):
-    """Create shapley schema for endpoint"""
-    name = endpoint.func.__name__
-    explainer = ShapExplainer(func=endpoint.func, X=endpoint.X)
-    folder = os.path.join(basepath, endpoint.func.__name__)
-    input_descriptions = [create_description(endpoint.X[col]) for col in endpoint.X]
+BASE_RESULTS_PATH = "results"
+
+
+def mkdir(endpoint, spec_path=""):
+    folder = os.path.join(BASE_RESULTS_PATH, endpoint.func.__name__, spec_path)
     if not os.path.exists(folder):
         os.makedirs(folder)
+    return folder
 
+
+def create_shapley_schema(endpoint):
+    """Create shapley schema for endpoint"""
+    x, y = endpoint.get_input_and_output_for_profiling()
+    explainer = ShapExplainer(func=endpoint.func, X=x)
+    folder = mkdir(endpoint=endpoint)
+    input_descriptions = [create_description(x[col]) for col in x.columns]
     logging.info("Shapley - Creating schema")
     fname = "schema.json"
     fpath = os.path.join(folder, fname)
@@ -33,12 +39,12 @@ def create_shapley_schema(endpoint, basepath="results"):
 def create_explainer_schema(endpoint, explainer, input_descriptions):
     """Create schema for explainer input"""
     # create an example
-    name = endpoint.func.__name__
-    X = endpoint.X.sample(n=1)
-    pred = endpoint.func(X)
-    baseline, explanation = explainer.explain(X)
+    x, y = endpoint.get_input_and_output_for_profiling()
+    x = x.sample(n=1)
+    pred = endpoint.func(x)
+    baseline, explanation = explainer.explain(x)
     example = {
-        "inputs": df_to_dict(X),
+        "inputs": df_to_dict(x),
         "explanations": df_to_dict(explanation),
         "prediction": list(pred),
         "baseline": list(baseline),
@@ -48,96 +54,83 @@ def create_explainer_schema(endpoint, explainer, input_descriptions):
     return schema
 
 
-def create_accuracy(endpoint, basepath="results"):
+def create_accuracy(endpoint):
     """Create accuracy profile for endpoint"""
+    x, y = endpoint.get_input_and_output_for_profiling()
     func = endpoint.func
-    X = endpoint.X
-    y = endpoint.y
-
-    kind = endpoint.kind
-    folder = os.path.join(basepath, func.__name__, "accuracy")
-    if not os.path.exists(folder):
-        os.makedirs(folder)
+    kind = endpoint.KIND.value
+    folder = mkdir(endpoint=endpoint, spec_path="accuracy")
 
     logging.info("Accuracy - Creating calibration plot")
     fname = "calibration.json"
     fpath = os.path.join(folder, fname)
-    chart = calibration(func, X, y)
+    chart = calibration(func, x, y)
     chart.save(fpath, format="json")
 
     logging.info("Accuracy - Creating metrics table")
     fname = "metrics.json"
     fpath = os.path.join(folder, fname)
-    metrics_table = metrics(func, X, y, kind)
+    metrics_table = metrics(func, x, y, kind)
     with open(fpath, "w") as f:
         f.write(metrics_table)
 
     logging.info("Accuracy - Finding largest errors")
     fname = "errors.json"
     fpath = os.path.join(folder, fname)
-    errors_table = largest_errors(func, X, y)
+    errors_table = largest_errors(func, x, y)
     with open(fpath, "w") as f:
         f.write(errors_table)
 
 
-def create_dependence(endpoint, basepath="results"):
+def create_dependence(endpoint):
     """Create partial dependence graphs for all variables"""
+    x, y = endpoint.get_input_and_output_for_profiling()
     func = endpoint.func
-    X = endpoint.X
-    y = endpoint.y
-    folder = os.path.join(basepath, func.__name__, "anatomy", "partialdep")
-    if not os.path.exists(folder):
-        os.makedirs(folder)
+    folder = mkdir(endpoint=endpoint, spec_path="anatomy/partialdep")
 
-    for var in X.columns:
+    for var in x.columns:
         logging.info(f"Explanations - Creating partial dependence for {var}")
         fname = var + ".json"
         fpath = os.path.join(folder, fname)
         try:
-            chart = partialdep(func, X, y, var)
+            chart = partialdep(func, x, y, var)
             chart.save(fpath, format="json")
         except AttributeError:
             logging.warning(f"Could not generate valid chart for {var}")
 
 
-def create_expectations(endpoint, basepath="results"):
+def create_expectations(endpoint):
     """Create conditional expectations graphs for all variables"""
+    x, y = endpoint.get_input_and_output_for_profiling()
     func = endpoint.func
-    X = endpoint.X
-    y = endpoint.y
-    folder = os.path.join(basepath, func.__name__, "anatomy", "condexp")
-    if not os.path.exists(folder):
-        os.makedirs(folder)
+    folder = mkdir(endpoint=endpoint, spec_path="anatomy/condexp")
 
-    for var in X.columns:
+    for var in x.columns:
         logging.info(f"Explanations - Creating conditional expectations for {var}")
         fname = var + ".json"
         fpath = os.path.join(folder, fname)
         try:
-            chart = condexp(func, X, y, var)
+            chart = condexp(func, x, y, var)
             chart.save(fpath, format="json")
-        except AttributeError:
-            logging.warning(f"Could not generate valid chart for {var}")
+        except AttributeError as e:
+            logging.warning(f"Could not generate valid chart for {var}: {repr(e)}")
 
 
-def create_importance(endpoint, basepath="results"):
+def create_importance(endpoint):
     """Create variable importance graphs"""
+    x, y = endpoint.get_input_and_output_for_profiling()
     func = endpoint.func
-    X = endpoint.X
-    y = endpoint.y
 
     logging.info("Explanations - Calculating variable importance")
-    if endpoint.kind == "regression":
-        chart, varlist = varimp(func, X, y, metric="Rmse")
-    elif endpoint.kind == "binary":
-        chart, varlist = varimp(func, X, y, metric="AUC")
+    if endpoint.KIND.value == "regression":
+        chart, varlist = varimp(func, x, y, metric="Rmse")
+    elif endpoint.KIND.value == "binary":
+        chart, varlist = varimp(func, x, y, metric="AUC")
     else:
-        raise NotImplementedError("Unknown endpoint kind:" + endpoint.kind)
+        raise NotImplementedError("Unknown endpoint kind:" + endpoint.KIND.value)
 
     # Save to disk
-    folder = os.path.join(basepath, func.__name__, "anatomy")
-    if not os.path.exists(folder):
-        os.makedirs(folder)
+    folder = mkdir(endpoint=endpoint, spec_path="anatomy")
 
     fname = "varimp.json"
     fpath = os.path.join(folder, fname)
@@ -149,13 +142,18 @@ def create_importance(endpoint, basepath="results"):
         json.dump(varlist, f)
 
 
-def create_summary(endpoint, basepath="results"):
+def create_summary(endpoint):
     endpoint_name = endpoint.func.__name__
+    logging.info(f"Summary - creating endpoint summary for endpoint: {endpoint_name}")
     as_json = {
         "name": endpoint_name,
-        "kind": endpoint.kind,
+        "kind": endpoint.KIND.value,
         "inputs": endpoint.input_names,
         "output": endpoint.output_names,
     }
-    with open(os.path.join(basepath, endpoint_name, "summary.json"), "w") as summary:
+    # Save to disk
+    folder = mkdir(endpoint=endpoint)
+    with open(os.path.join(folder, "summary.json"), "w") as summary:
         json.dump(as_json, summary)
+
+
